{% extends "base_with_header.html"%}
  
{%block PAGE_CONTENT%}
     {{view_object.html_content | safe }}     
     
     <div id="disqus_thread"></div>
<script>

/**
*  RECOMMENDED CONFIGURATION VARIABLES: EDIT AND UNCOMMENT THE SECTION BELOW TO INSERT DYNAMIC VALUES FROM YOUR PLATFORM OR CMS.
*  LEARN WHY DEFINING THESE VARIABLES IS IMPORTANT: https://disqus.com/admin/universalcode/#configuration-variables*/

var disqus_config = function () {
this.page.url = "http://www.fedora-install-howto.com/{{view_object.get_absolute_url}}";  // Replace PAGE_URL with your page's canonical URL variable
this.page.identifier = "{{view_object.title_sha1sum}}"; // Replace PAGE_IDENTIFIER with your page's unique identifier variable
};

(function() { // DON'T EDIT BELOW THIS LINE
var d = document, s = d.createElement('script');
s.src = 'https://www-fedora-install-howto-com.disqus.com/embed.js';
s.setAttribute('data-timestamp', +new Date());
(d.head || d.body).appendChild(s);
})();
</script>
<noscript>Please enable JavaScript to view the <a href="https://disqus.com/?ref_noscript">comments powered by Disqus.</a></noscript>
                            
{%endblock PAGE_CONTENT%}
      
 
{%block BOTTOM_HTML %}
<!--bottom html-->


{% if view_object.request.user.username == "admin" %}

    {% load pageadmin_tags %}
    {# PageAdmin will load the admin html which is usually hidden. #}
    {% PageAdmin %}

    <!--Required JavaScript for PageAdmin -->
   
    <script src="/static/mycms/vendor/fileinput/js/plugins/sortable.js" type="text/javascript"></script>
    <script src="/static/mycms/vendor/fileinput/js/fileinput.js" type="text/javascript"></script>
    <script src="/static/mycms/vendor/fileinput/js/locales/fr.js" type="text/javascript"></script>
    <script src="/static/mycms/vendor/fileinput/js/locales/es.js" type="text/javascript"></script>
    <script src="/static/mycms/vendor/fileinput/js/plugins/piexif.js" type="text/javascript"></script>
    <script src="/static/mycms/vendor/fileinput/themes/fas/theme.js" type="text/javascript"></script>
    <script src="/static/mycms/vendor/fileinput/themes/explorer-fas/theme.js" type="text/javascript"></script>
 
 
 
    <script type="text/javascript" src="/static/mycms/dustjs/dust-full.js"></script>
    <script type="text/javascript" src="/static/mycms/js/admin.js"></script>

<script>



$(document).ready(function () {
  
    log.setLevel(log.levels.DEBUG);
    
    //log.debug("document.ready on page reached.");
    //log.info("This is an info");
    //log.warn("This is a warning");
    //log.error("This is a fatal error");
    
      
});
    
  
</script -->























{%endif%}




<!-- end-->
{%endblock BOTTOM_HTML %}
</body>
</html>
