#!/usr/bin/env python
# coding: utf-8

"""
    python-creole exceptions
    ~~~~~~~~~~~~~~~~~~~~~~~~
    
    :copyleft: 2011 by python-creole team, see AUTHORS for more details.
    :license: GNU GPL v3 or above, see LICENSE for more details.
"""

from __future__ import division, absolute_import, print_function, unicode_literals


class DocutilsImportError(ImportError):
    pass
