 <!-- Search Widget -->
        <div class="card my-4">
          <h5 class="card-header">Search</h5>
          <div class="card-body">
            <div class="input-group">
            <form class="form-inline" action="/cms/search/" method="get">
              <input type="text" class="form-control"  type="search" name="q" id="id_q" class="form-control lg"  placeholder="Search for...">
            
                <button class="btn btn-secondary" type="submit">Go!</button>
                        </form>
            </div>
          </div>
        </div>