#show-admin-overlay-button{
    position: fixed;
    bottom: 10px;
    left: 10px;
    z-index: 2049;
    width: 30px;
    height: 30px;
}

#overlay {
    position: fixed;
    display: none;
    width: 100%;
    height: 100%;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    background-color: rgba(0,0,0,0.5);
    cursor: pointer;
    overflow-y: scroll;
    z-index: 2050;
    margin-top: 10px;
}

#admin-tabs{
    background-color:#555;
    border: 1px solid transparent;
    border-top-left-radius: .25rem;
    border-top-right-radius: .25rem;
    
}

#admin-pane{
    position: relative;
    padding-left: 15px;
    padding-right: 15px;
    height:90%;
    margin-top:10px;

}

#admin-pane ul {
    background-color: #grey;
    border-top-left-radius: 5px;
    border-top-right-radius: 5px;    
}

#admin-tabs-container {
    background: white;
    height:100%;
    //border-top-left-radius: 5px;
    //border-top-right-radius: 5px;
}

#creole-editor-pane{
    height:100%;
}


#creole-editor-icons button {
background: #ddd;
font-color:black;
color:black;
}

.nav-tabs {
 border-bottom: #fff;
}


.grey-background {
    background-color:#ccc;
}

#creole-editor-icons{
    background-color:#FFF;
}


#editor-container{
    height:100%;
    padding:5px;
}

#editor-container form{
    height:100%;
}


#editor-container textarea{
    height:90%;
    //padding-left:10px;
    //padding-right:10px;
    margin:auto;
    width:100%;
    resize: none;
    padding:5px;
}



#close-admin-overlay-button {
    position: relative;
    margin-right: 5px;
    margin-top:5px;
    margin-left: auto;
    float:right;
    width:30px;
    height:30px;
}

.editor-icon {
    padding: 2px;
    margin-top:3px;
    margin-bottom:3px;
    width:32px;
    color:#ddd;
    margin-left:5px;
    background-color:#adb5bd;
    height: 35px;
}

.editor-icon-checkbox{
    width:72px;
    font-size:9px;
    background-color:#5385A1;
    
}


.icon-label {
  display: block;
  padding-left: 2px;
  text-indent: -2px;
  padding-top:5px;
}

input {
  width: 12px;
  height: 12px;
  padding: 0;
  margin:0;
  vertical-align: bottom;
  position: relative;
  top: -1px;
  *overflow: hidden;
}


#su
#fileupload-container{

    padding:15px;
    height:100%;

}

#fileupload-container{
    height:100%;
    background-color:#FFF;
}





.pad-sm{
    padding:2px;
}

.pad-10{
 //   padding-left:17px;
 //padding-right:17px;
}

#cmsentries-editor-pane{
    height:100%;
    background-color:white;
}

#cmsentries-admin-container{
    height:100%;
    background-color:white;

}

.cmsentries-admin-row{
    margin-left:0px;
    margin-right:0px;
    background-color:white;
}

.create-cms-entry-button{
    float:right;

}



#cmsentries-table-row thead {
    background-color: #5385A1;
    color:#fff;

}

#cmsentries-table-row th {
    padding:2px;
    margin-left:2px;
    margin-right:2px;

}

