


    <li class="sep"></li>
    <li class="primary">
        {% if parent.categories %}
            <a href="/cms{{parent.path}}" class="firstLevel hasSubMenu">{{parent.title}}</a>
            <ul class="subMenu">
                {% for child in parent.categories %}
                    {% if child.categories %} 
                    <li class="dropdownSubmenu">
                        <a href="{{child.path}}" class="hasSubMenu">{{child.title}}</a>
                            <ul class="subMenu" style="display: none; left: 0px;">
                             {%for grandchild in child.categories %}
                                <li><a href="{{grandchild.path}}">{{grandchild.title}}</a></li>
                            {%endfor%}
                            </ul>
                    </li>
                    {% else %}
                    <li><a href="/cms{{child.path}}">{{child.title}}</a></li>
                    {% endif %}
                
                 {%endfor%}
            
        
            </ul>    
            
        {% else %}
        <a href="/cms{{parent.path}}" class="firstLevel">{{parent.title}}</a>    
        {% endif %}
    </li>
    
    