# -*- coding: utf-8 -*-
# Generated by Django 1.11.10 on 2018-06-26 14:01
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mycms", "0003_cmsentries_lists_include"),
    ]

    operations = [
        migrations.AddField(
            model_name="cmsentries",
            name="logo_url",
            field=models.CharField(
                blank=True,
                default="/static/mycms/images/png/default.png",
                max_length=1024,
                null=True,
            ),
        ),
    ]
