
{% for cmsentry in cmsentries %}
<article class="post clearfix">    
    <div class="row">
        <section class="col-sm-11 article-summary">
            <!-- article title -->
            <h2><a href="/cms/{{cmsentry.path}}">{{cmsentry.title}}</a></h2>
            
            <!-- article description -->
            <p style="display: inline">{{ cmsentry.view.introduction|safe|truncatewords_html:50 }}
                <a href="/cms/{{cmsentry.path}}" class="readMore">read more</a>
            </p>
            
            <!-- article meta icons -->
            <ul class="entry-meta">
                <li class="entry-date">
                    <a href="#">
                        <i class="icon-pin"></i>
                        &nbsp;{{cmsentry.view.created_timestamp_str}}
                    </a>
                </li>
                <li class="entry-category">
                    <a href="/cms{{cmsentry.parent.path.path}}">
                        <i class="icon-th-list"></i>
                        &nbsp;{{cmsentry.parent.title}}
                    </a>
                </li>
                <li class="entry-author">
                    <a href="#"><i class="icon-male">
                        </i>&nbsp;Admin</a>
                </li>
                <!-- li class="entry-comments"><a href="#"><i class="icon-comment-1"></i>&nbsp;12 comments</a></li -->
            </ul>
        </section>
    </div>
</article>
<hr>
 {% endfor %}
 
 
 
 - 299,78 euros