# -*- coding: utf-8 -*-
# Generated by Django 1.11.10 on 2018-06-13 12:24
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mycms", "0002_cmsarchivesindex"),
    ]

    operations = [
        migrations.AddField(
            model_name="cmsentries",
            name="lists_include",
            field=models.BooleanField(default=True),
        ),
    ]
