<ul id="editor-buttons">
    <li><button class="btn btn-default" type="submit" onclick="formatButtonHandler('H1')">H1</button></li>
    <li><button class="btn btn-default" type="submit" onclick="formatButtonHandler('H2')">H2</button></li>
    <li><button class="btn btn-default" type="submit" onclick="formatButtonHandler('H3')">H3</button></li>
    <li><button class="btn btn-default" type="submit" onclick="formatButtonHandler('H4')">H4</button></li>
    <li><button class="btn btn-default" type="submit" onclick="formatButtonHandler('H5')">H5</button></li>
    <li><button class="btn btn-default" type="submit" onclick="readCMSContents(1)">Read</button></li>
    <li><button class="btn btn-default" type="submit" onclick="previewCMSContent(1)">Preview</button></li>
    <li><button class="btn btn-default" type="submit" onclick="updateCMSContents(1)">Update</button></li>
    <li><div class=btn btn-default><span>Published</span><input type="checkbox" value="" id="published_checkbox"></input></div></li>
     <li><div class=btn btn-default><span>FrontPage</span><input class="form-check-input" type="checkbox" value="" id="frontpage_checkbox"></input></div></li>
     
</ul>
<div id="editor-pane">
    <textarea id="markup"></textarea>
</div>





