  <option value="index.html">Home</option>


  {% for child in parent.categories%}
    <option value="/cms/{{child.path}}">{{child.title}}</option>

        {% for grandchild in child.categories %}
            <option value="/cms/{{grandchild.path}}"> - {{grandchild.title}}</option>

                         {% for greatgrandchild in grandchild.categories %}
                         <option value="/cms/{{greatgrandchild.path}}">   - {{greatgrandchild.title}}</option>
                         {% endfor %}
        </li>
        {% endfor %}

    {% endfor %}

















